#!/bin/bash
if : ; then
# File:         help_commands.sh
# Name:         Kevin Crotty
# Date:         19 Mar 2019
# Desc:         Display common usage of common help commands in bash.
# Usage:        ./help_commands.sh

# Set Colors for use in the script
export NC='\e[0m'               # Text Reset
export BBlack='\e[1;30m'        # Black
export BRed='\e[1;31m'          # Red
export BGreen='\e[1;32m'        # Green
export BYellow='\e[1;33m'       # Yellow
export BBlue='\e[1;34m'         # Blue
export BPurple='\e[1;35m'       # Purple
export BCyan='\e[1;36m'         # Cyan
export BWhite='\e[1;37m'        # White

function colorComment { echo -e "\n${BGreen}${1}${NC}"
}
function colorCommand { echo -e "${BRed}${1}${NC}"
}
fi

reset

echo -e "\n${BPurple}List of helpful commands with a brief description${NC}"

colorComment "# Open the command manual(stored locally) in a page viewer"
echo -e "${BGreen}# You can optionally specify the manual section for words ambiguous entries"
echo -e "${BGreen}# In this case the ${BPurple}'1'${BGreen} refers to the command ${BPurple}/usr/bin/passwd${BGreen} and the ${BCyan}'5'${BGreen} refers to the file ${BCyan}/etc/passwd"
colorCommand "\$ man ${BPurple}1${BRed} passwd"
colorCommand "\$ man ${BCyan}5${BRed} passwd"

colorComment "# Indicate how it would be interpreted if used as a command name"
colorCommand "\$ type grep"
echo -e "grep is aliased to 'grep --color=auto'"

colorCommand "\n\$ type -a grep"
echo -e "grep is aliased to 'grep --color=auto'"
echo -e "grep is /bin/grep"

colorCommand "\n\$ type cd"
echo -e "cd is a shell builtin"

colorComment "# Returns the pathnames of the files (or links) which would be executed in the current environment"
colorCommand "\$ which sudo"
echo -e "/usr/bin/sudo"

colorCommand "\n\$ which ls"
echo -e "/bin/ls"

colorComment "# Searches the man pages and descriptions"
colorCommand "\$ apropos find"
echo -e "File::IconTheme (3pm) - find icon directories"
echo -e "File::MimeInfo::Applications (3pm) - Find programs to open a file by mimetype"
echo -e "File::UserDirs (3pm) - find extra media and documents directories"
echo -e "find (1)             - search for files in a directory hierarchy"
echo -e "findfs (8)           - find a filesystem by label or UUID"
echo -e "${BCyan}-- Snip --${NC}"

colorComment "# Show command options"
colorCommand "\$ cat --help"
echo -e "Usage: head [OPTION]... [FILE]..."
echo -e "Print the first 10 lines of each FILE to standard output."
echo -e "With more than one FILE, precede each with a header giving the file name."

echo -e "With no FILE, or when FILE is -, read standard input."

echo -e "Mandatory arguments to long options are mandatory for short options too."
echo -e "  -c, --bytes=[-]NUM       print the first NUM bytes of each file;"
echo -e "${BCyan}-- Snip --${NC}"

colorComment "# Show command options"
colorCommand "\$ help cd"
echo -e "cd: cd [-L|[-P [-e]] [-@]] [dir]"
echo -e "    Change the shell working directory."

echo -e "    Change the current directory to DIR.  The default DIR is the value of the"
echo -e "    HOME shell variable."
echo -e "${BCyan}-- Snip --${NC}"

colorComment "# Display one-line manual page descriptions"
colorCommand "\$ whatis ls"
echo -e "ls (1)               - list directory contents"

colorComment "# Locate the binary, source, and manual page files for a command"
colorCommand "\$ whereis ls"
echo -e "ls: /bin/ls /usr/share/man/man1/ls.1.gz"

colorComment "# Determines File type (can be tricked)"
colorCommand "\$ file /etc/passwd"
echo -e "/etc/passwd: ASCII text"

colorCommand "\n\$ file script.sh"
echo -e "script.sh: Bourne-Again shell script, ASCII text executable"

colorCommand "\n\$ file /bin/cat"
echo -e "/bin/cat: ELF 64-bit LSB shared object, x86-64, version 1 (SYSV), dynamically linked, interpreter /lib64/l, for GNU/Linux 3.2.0, BuildID[sha1]=747e524bc20d33ce25ed4aea108e3025e5c3b78f, stripped"

echo && echo
