#!/bin/bash
  : ' File:         compressions.sh
  # Name:         Greg Shrewsbury
  # Date:         21Apr2020
  # Desc:         Provide description of file compression types in liunx
  # Usage:        ./script.sh OR source script.sh'

##### COLOR VARIABLES AND FUNCTIONS ######
export NC='\e[0m'               # Text Reset
export BBlack='\e[1;30m'        # Black
export BRed='\e[1;31m'          # Red
export BGreen='\e[1;32m'        # Green
export BYellow='\e[1;33m'       # Yellow
export BBlue='\e[1;34m'         # Blue
export BPurple='\e[1;35m'       # Purple
export BCyan='\e[1;36m'         # Cyan
export BWhite='\e[1;37m'        # White


##### FUNCTIONS #####
about_7z () {
reset
echo -e "${BRed}	--- .7z ---"
echo -e "${BGreen} 	7-Zip is a file archiver with the highest compression ratio and supports ZIP, CAB, ARJ, GZIP, BZIP2, TAR, CPIO, RPM and DEB formats. 
	Common syntax is ${BPurple} <7z ${BRed}a ${BPurple}[file name>].7z /path/to/folder /path/to/file for createing an archive,${BGreen} and ${BPurple} <7z ${BRed}e ${BPurple}[file name].7z> for extract."
}
about_gzip () {
reset
echo -e "${BRed}	--- .gzip ---"
echo -e "${BGreen}	gzip works with gzip (".gz") files, not zip (".zip") files. For zip files, you need to use the unzip command. 
	Common syntax is ${BPurple} <gzip [option] [filename]> to create a file and <gzip ${BRed}–d ${BPurple}[filename]> to ${BRed}decompress."
}
about_bzip2 () {
reset
echo -e "${BRed}	--- .bzip2 ---"
echo -e "${BGreen}	bzip2 is a proprietary free compression algorithm and it follows the familiar syntax when compression a file.
	Common syntax is ${BPurple} <bzip2 [OPTIONS] filenames> to compress and <bzip2 ${BRed}-d ${BPurple}filename.bz2> to ${BRed}decompress."
}
about_tar () {
reset
echo -e "${BRed}	--- .tar ---"
echo -e "${BGreen}	Or tape archives aka tarballs are used when compressing multiple files or directories. They can then also be compressed or zipped into a gzip file. This type of file will end in a .tar.gz or .tgz file extension. Gzip is most often used to compress text files, Tar archives, and web pages.
	Common syntax is ${BPurple} <tar ${BRed}-c${BPurple}vf [new file name.tar.gz] /path/to/directory> to ${BRed}create ${BPurple}tar file. <tar ${BRed}-x${BPurple}vf [file name to decompress] to ${BRed}decompress ${BPurple}a tar."
}
mainMenu () {
reset
while :
do
        echo
        echo -e "${BRed}Choose from the following options:"
        echo -e "${BGreen}----------------------------------"
        echo "   [1] .7z"
        echo "   [2] .gzip"
        echo "   [3] .bzip2"
        echo "   [4] .tar"
        echo
        echo -e "${BRed}   [X] to Exit : [C] to Clear the Screen" && echo
        read -p "Choice: " choice
        echo
        case $choice in
	 1) about_7z
                      ;;
              2) about_gzip
                      ;;
              3) about_bzip2
                      ;;
              4) about_tar
                      ;;
              [xX]) return 0
                      ;;
              [cC])  reset
                      ;;
              *) echo "Please enter a valid option"
                      ;;
      esac
done
}
# RUN THE PROGRAM
mainMenu

