#!/bin/bash
if : ; then
# File:         loops.sh
# Name:         Kevin Crotty
# Date:         31 Mar 2019
# Desc:         Loops in Bash
# Usage:        ./loops.sh

# Set Colors for use in the script
export NC='\e[0m'               # Text Reset
export BBlack='\e[1;30m'        # Black
export BRed='\e[1;31m'          # Red
export BGreen='\e[1;32m'        # Green
export BYellow='\e[1;33m'       # Yellow
export BBlue='\e[1;34m'         # Blue
export BPurple='\e[1;35m'       # Purple
export BCyan='\e[1;36m'         # Cyan
export BWhite='\e[1;37m'        # White

: ' The two functions below colorize
    comments in green, and
    commands in red.'

function colorComment { echo -e "\n${BGreen}${1}${NC}"
}
function colorCommand { echo -e "${BRed}${1}${NC}"
}
fi

reset

colorComment "# For loop using command substitution"
echo -e "${BGreen}# NOTE: Results may vary based on what the IFS is set to.${NC}"
colorCommand "for i in \$(head -n3 /etc/passwd) ; do echo \"\$i\" ; done"
echo -e "root:x:0:0:root:/root:/bin/bash"
echo -e "daemon:x:1:1:daemon:/usr/sbin:/usr/sbin/nologin"
echo -e "bin:x:2:2:bin:/bin:/usr/sbin/nologin"


colorComment "# For loop with C like syntax"
colorCommand "for ((i = 0 ; i < 10 ; i++)); do"
colorCommand "echo -n \"\$i \""
colorCommand "done"
echo -e "0 1 2 3 4 5 6 7 8 9 "

colorComment "# For loop that iterates over a range"
colorCommand "for i in {1..5}; do"
colorCommand "echo "\$i""
colorCommand "done"
echo -e "1"
echo -e "2"
echo -e "3"
echo -e "4"
echo -e "5"

colorComment "# For loop that iterates over a step"
colorCommand "for i in {5..50..10}; do"
colorCommand "echo \"Step \$i\""
colorCommand "done"
echo -e "Step 5"
echo -e "Step 15"
echo -e "Step 25"
echo -e "Step 35"
echo -e "Step 45"

colorComment "# While loop that reads lines from a file"
colorCommand "while read line;"
colorCommand "do"
colorCommand "echo "\$line ""
colorCommand "done < /etc/shells"
echo -e "# /etc/shells: valid login shells"
echo -e "/bin/sh"
echo -e "/bin/bash"
echo -e "/bin/rbash"
echo -e "/bin/dash"
echo -e "/usr/bin/tmux\n\n"
