#!/bin/bash
if : ; then
# File:         sed.sh
# Name:         Kevin Crotty
# Date:         1 Apr 2019
# Desc:         Sed Basics
# Usage:        ./sed.sh

# Set Colors for use in the script
export NC='\e[0m'               # Text Reset
export BBlack='\e[1;30m'        # Black
export BRed='\e[1;31m'          # Red
export BGreen='\e[1;32m'        # Green
export BYellow='\e[1;33m'       # Yellow
export Blue='\e[0;34m'         # Blue
export BBlue='\e[1;34m'         # Blue
export BPurple='\e[1;35m'       # Purple
export BCyan='\e[1;36m'         # Cyan
export BWhite='\e[1;37m'        # White

: ' The two functions below colorize
    comments in green, and
    commands in red.'

function colorComment { echo -e "\n${BGreen}${1}${NC}"
}
function colorCommand { echo -e "${BRed}${1}${NC}"
}
fi
reset

colorComment "# Generate some different encoded lines"
colorCommand "echo 'First_Line' | base64 >> encoded.del"
colorCommand "echo 'Second Line' | base32 >> encoded.del"
echo -e "${BGreen}# Needs extra newline to decode properly"
colorCommand "echo 'The Third Line' | base58 >> encoded.del; echo >> encoded.del"

colorComment "# Show the encoded text"
colorCommand "cat encoded.del"
echo -e "Rmlyc3RfTGluZQo="
echo -e "KNSWG33OMQQEY2LOMUFA===="
echo -e "Y2osUScHqigKhYJR3ue"

colorComment "# For each line, attempt to decoded it, and save all output to decoded.del"
colorCommand "while read line"
colorCommand "do"
colorCommand "    echo \"\$line\" | base64 -d 2>/dev/null >> decoded.del; echo >> decoded.del"
colorCommand "    echo \"\$line\" | base32 -d 2>/dev/null >> decoded.del; echo >> decoded.del"
colorCommand "    echo \"\$line\" | base58 -d 2>/dev/null >> decoded.del; echo >> decoded.del"
colorCommand "done < encoded.del"

#colorComment "#  The individual tr commands are necessarry when using the delete option"
#echo -e "${BGreen}#+ The ASCII octal ranges are split so that things like 'newline' characters are preserved${NC}"

#colorComment "# Delete all the byte patterns that match Octal 1-7 (Non-Rendering Symbols)"
#colorCommand "LC_ALL=C tr -d '\1-\7' < decoded.del > tmp && mv tmp decoded.del"
#colorComment "# Delete all the byte patterns that match Octal 20-37 (Non-Rendering Symbols)"
#colorCommand "LC_ALL=C tr -d '\20-\37' < decoded.del > tmp && mv tmp decoded.del"
#colorComment "# Delete all remaining bytes outside of the ASCII range"
#colorCommand "LC_ALL=C tr -dc '\0-\177' < decoded.del > final.del"

colorComment "# Use strings command to get rid of unreadable characters"
colorCommand "strings decoded.del"
echo -e "First_Line"
echo -e "Second Line"
echo -e "cj,Q'"
echo -e "The Third Line"

colorComment "# Cleanup"
colorCommand "rm *.del 2>/dev/null"
echo -e "\n\n\n"
