#!/bin/bash
# File:         sed.sh
# Name:         Kevin Crotty
# Date:         1 Apr 2019
# Desc:         Sed Basics
# Usage:        ./sed.sh

# Set Colors for use in the script
export NC='\e[0m'               # Text Reset
export BBlack='\e[1;30m'        # Black
export BRed='\e[1;31m'          # Red
export BGreen='\e[1;32m'        # Green
export BYellow='\e[1;33m'       # Yellow
export Blue='\e[0;34m'         # Blue
export BBlue='\e[1;34m'         # Blue
export BPurple='\e[1;35m'       # Purple
export BCyan='\e[1;36m'         # Cyan
export BWhite='\e[1;37m'        # White

reset

echo -e "${BGreen}#++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++#"
echo -e "${BGreen}#  The following methods should work for all ${BRed}Debian${BGreen} based Linux Distributions      #${NC}"
echo -e "${BGreen}#+ See the link in the Student FG for the difference between 'apt' and 'apt-get'   #${NC}"
echo -e "${BGreen}#++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++#\n\n"

echo -e "${BBlue}--Use common utilities apt and apt/get--"
echo -e "${BGreen}#  Setting this environment variable in a script that installs packages will tell${NC}"
echo -e "${BGreen}#+ the current shell to use the default options, instead of prompting the user${NC}"
echo -e "${BRed}DEBIAN_FRONTEND=noninteractive\n${NC}"
echo -e "${BGreen}# Typical command format a website will provide in to download their PROGRAM${NC}"
echo -e "${BRed}apt update -y && apt install ${BCyan}\$PROGRAM${BRed} -y\n${NC}"
echo -e "${BGreen}#  If you have downloaded the '.deb' Debian package file, you can use apt to install it.${NC}"
echo -e "${BGreen}#+ NOTE: You have to provide a absoulte or relative path for this method to work.${NC}"
echo -e "${BRed}apt install -y ./${BCyan}\$FILENAME${BRed}.deb\n${NC}"
echo -e "${BGreen}#  Even after successful installation commands, some programs are still missing dependencies.${NC}"
echo -e "${BGreen}#+ This command will fix 99% of those problems.${NC}"
echo -e "${BRed}apt-get -f install\n\n${NC}"

echo -e "${BBlue}--Git Clone an Open Source Repo--"
echo -e "${BGreen}#  Alot of Open Source programs allow your to download their repo, and build the${NC}"
echo -e "${BGreen}#+ most up to date version from the source files.${NC}"
echo -e "${BGreen}#+ 'PROGRAM' is just the name of the folder to save the repo to.${NC}"
echo -e "${BCyan}REPO_URL${BRed}=${BPurple}'https://git.cybbh.space/os/public.git'${NC}"
echo -e "${BRed}git clone ${BCyan}\$REPO_URL${BRed} ${BCyan}\$PROGRAM${BRed}${NC}"
echo -e "${BGreen}#  The 'make' command will run a series of commands saved to a 'Makefile' located${NC}"
echo -e "${BGreen}#+ in the repo, so you don't have to.${NC}"
echo -e "${BRed}cd ${BCyan}\$PROGRAM${BRed} && make install\n\n${NC}"

echo -e "${BBlue}--Use Python Installer--"
echo -e "${BGreen}#  Alot of programs in linux are actually written in python, and can be installed${NC}"
echo -e "${BGreen}#+ using their custom 'Pip installs packages'(PIP) program${NC}"
echo -e "${BRed}pip install -y ${BCyan}\$PROGRAM${BRed}\n\n${NC}"

echo -e "${BBlue}- Use a web script--"
echo -e "${BGreen}#  Sometimes you can simply curl an install script from a public source and pipe it directly${NC}"
echo -e "${BGreen}#+ to bash, and let it do all the work. WARNING: Look at the code first just in case.${NC}"
echo -e "${BRed}curl ${BCyan}\$INSTALL_URL${BRed} | bash\n\n\n${NC}"
