#!/bin/bash
if : ; then
# File:         ipc.sh
# Name:         Kevin Crotty
# Date:         21 Mar 2019
# Desc:         Illustrate's relationship between IPC communication
# Usage:        ./ipc.sh

# Set Colors for use in the script
export NC='\e[0m'               # Text Reset
export BBlack='\e[1;30m'        # Black
export BRed='\e[1;31m'          # Red
export BGreen='\e[1;32m'        # Green
export BYellow='\e[1;33m'       # Yellow
export BBlue='\e[1;34m'         # Blue
export BPurple='\e[1;35m'       # Purple
export BCyan='\e[1;36m'         # Cyan
export BWhite='\e[1;37m'        # White

function colorComment { echo -e "\n${BGreen}${1}${NC}"
}
function colorCommand { echo -e "${BRed}${1}${NC}"
}
fi
reset

colorComment "# Creates an 'incomplete pipe' scenario between the two commands"
echo -e "${BRed}ls -l /etc/ | less 2>/dev/null &${NC}"
echo -e "[2] ${BCyan}${BCyan}31430${NC}${NC}"
echo
echo -e "[2]+  Stopped                 \ls -l /etc/ | less 2> /dev/null${NC}"
colorComment "# Finds the PID's of both commands"
echo -e "${BRed}ps -elf --forest | grep pts | grep -v grep | grep -E \"(ls|less)\"${NC}"
echo -e "F S UID      PID   PPID   C  PRI  NI   ADDR SZ WCHAN  STIME TTY      TIME         CMD"
echo -e "0 T root     ${BCyan}31429${NC} 30148  0  80   0 -  3711 -         00:46 pts/1    00:00:00      \_ ls -l /etc/${NC}"
echo -e "0 T root     ${BCyan}31430${NC} 30148  0  80   0 -  2040 -         00:46 pts/1    00:00:00      \_ less${NC}"
colorComment "# Use 'lsof' to see all the different file descriptors open for both commands"

echo -e "${BRed}lsof 2>/dev/null |grep -v DIR | grep -v REG | grep -P '(\s${BCyan}31429${NC}${BRed}\s|\s${BCyan}31430${BRed}\s)'${NC}"
echo -e "COMMAND   PID   TID         USER    FD     TYPE             DEVICE  SIZE/OFF      NODE NAME"
echo -e "ls        ${BCyan}31429${NC}             root    0u      CHR              136,1      0t0          4 /dev/pts/1${NC}"
echo -e "ls        ${BCyan}31429${NC}             root    1w     FIFO               0,10      0t0    ${BPurple}1029865${NC} pipe${NC}"
echo -e "ls        ${BCyan}31429${NC}             root    2u      CHR              136,1      0t0          4 /dev/pts/1${NC}"
echo -e "less      ${BCyan}31430${NC}             root    0r     FIFO               0,10      0t0    ${BPurple}1029865${NC} pipe${NC}"
echo -e "less      ${BCyan}31430${NC}             root    1u      CHR              136,1      0t0          4 /dev/pts/1${NC}"
echo -e "less      ${BCyan}31430${NC}             root    2w      CHR                1,3      0t0       1028 /dev/null${NC}"
echo -e "less      ${BCyan}31430${NC}             root    3r      CHR                5,0      0t0       1035 /dev/tty${NC}"
colorComment "# View the association between FD's and the 'pipe' file"
echo -e "${BRed}ls -l /proc/{${BCyan}31429${NC},${BCyan}31430${NC}${BRed}}/fd${NC}"
echo
echo -e "/proc/${BCyan}31429${NC}/fd:${NC}"
echo -e "lrwx------  root  root   -  Thu Apr  4 01:29:24 2019    0 ⇒ /dev/pts/1${NC}"
echo -e "l-wx------  root  root   -  Thu Apr  4 01:29:24 2019    1 ⇒ pipe:[${BPurple}1029865${NC}]${NC}"
echo -e "lrwx------  root  root   -  Thu Apr  4 01:29:24 2019    2 ⇒ /dev/pts/1${NC}"
echo
echo -e "/proc/${BCyan}31430${NC}/fd:${NC}"
echo -e "lr-x------  root  root   -  Thu Apr  4 01:29:24 2019    0 ⇒ pipe:[${BPurple}1029865${NC}]${NC}"
echo -e "lrwx------  root  root   -  Thu Apr  4 01:29:24 2019    1 ⇒ /dev/pts/1${NC}"
echo -e "l-wx------  root  root   -  Thu Apr  4 01:29:24 2019    2 ⇒ /dev/null${NC}"
echo -e "lr-x------  root  root   -  Thu Apr  4 01:29:24 2019    3 ⇒ /dev/tty${NC}"
colorComment "# View the 'lsof' results on the inode of the pipe, and the association between the file descriptors"
echo -e "${BRed}lsof 2>/dev/null | grep ${BPurple}1029865${NC}${NC}"
echo -e "COMMAND   PID   TID         USER    FD     TYPE             DEVICE  SIZE/OFF      NODE NAME"
echo -e "ls        ${BCyan}31429${NC}             root    1w     FIFO               0,10      0t0    ${BPurple}1029865${NC} pipe${NC}"
echo -e "less      ${BCyan}31430${NC}             root    0r     FIFO               0,10      0t0    ${BPurple}1029865${NC} pipe${NC}\n\n"
