#!/bin/bash

# File:         qemu-mount.sh
# Name:         Joseph Gerwing
# Date:         20200213
# Desc:         Automate mounting of fun.vdi filesystem
# Usage:        source qemu-mount.sh

# Color Variables
export BRED="\e[91m"
export BGREEN="\e[92m"
export BCYAN="\e[96m"
export NC="\e[0m"

# Function for highlighting commands
colorcommand () {
   echo -e "${BRED}$1${NC}"
}

# Function for highlighting comments
colorcomment () {
  echo -e "${BGREEN}$1${NC}"
}


clear

# Simulating load timer for mount commands
echo -ne "${BGREEN}Mounting VDI filesytem" && sleep .9 && echo -ne "." && sleep .9 && echo -ne "." && sleep .9 && echo -e ".${NC}"

# Change directory to $HOME where fun.vdi is
echo -ne "${BGREEN}Changing directories to ${CYAN}\$HOME${BGREEN}..." && sleep .9 && echo -e "${BRED}cd${NC}"
cd

# Connects nbd0 to fun.vdi
echo -ne "${BGREEN}Connecting nbd0 device to fun.vdi..." && sleep .9 && echo -e "${BRED}qemu-nbd -c /dev/nbd0 \$PWD/fun.vdi${NC}"
qemu-nbd -c /dev/nbd0 $PWD/fun.vdi

# Verifies VDI associated device (nbd0p1) exists.
echo -ne "${BGREEN}Verifying VDI associated device (nbd0p1) is there..." && sleep .9 && echo -e "${BRED}ls /dev/ndb0p1${NC}"
ls /dev/nbd0p1

# Mounts VDI associated device to 'fun' mount point.
echo -ne "${BGREEN}Mounting VDI associated device (nbd0p1) to ${BCYAN}fun${BGREEN}..." && sleep .9 && echo -e "${BRED}mount /dev/nbd0p1 fun${NC}"
mount /dev/nbd0p1 fun

# Verifying we are mounted.
echo -ne "${BGREEN}Verifying mount point exists..." && sleep .9 && echo -e "${BRED}df -h | egrep nbd0p1${NC}"
df -h | egrep nbd0p1

# Change to mount point
echo -ne "${BGREEN}Changing directories to ${CYAN}fun${BGREEN}..." && sleep .9 && echo -e "${BRED}cd fun${NC}"
cd fun

# List directory contents of VDI filesystem
echo -e "${BGREEN}Listing directory contents for ${CYAN}fun${BGREEN}..." && sleep .9 && echo -e "${RED}ls${NC}"
ls

# Fancy
colorcomment "LETS" && sleep .9
colorcomment "    FIX" && sleep .9
colorcomment "       SOME" && sleep .9
colorcomment "           FILES!"
