#!/bin/bash
# File:         mycp.sh
# Name:         Kevin Crotty
# Date:         29 Mar 2019
# Desc:         Show File Descriptor Manipulation
# Usage:        source mycp.sh

#+		 	First	  type mycp
#+			Second    mycp
#+ 			Third	  mycp /etc/shells
#+ 			Fourth    mycp /etc/shells outfile && cat outfile && rm outfile


#  This function accepts 0, 1, or 2 files as arguements.
#+ With a single 'cat' command as the only real command,
#+ that functions according to how the corresponding file
#+ descriptors are set.

function mycp () {
	case $# in
		0)
		# -- Zero arguements
			#  FD(3) duplicates STDIN
			#  FD(4) duplicates STDOUT
			exec 3<&0 4<&1
			;;
		1)
		# -- One arguement
			#  Open the file named by the arguement for input and associate it with FD(3)
			#  FD(4) duplicates STDOUT
			exec 3< $1 4<&1
			;;
		2)
		# -- Two arguements
			#  Open the file named by the first arguement for input and associate it with FD(3)
			#  Open the file named by the second arguement for output and associate it with FD(4)
			exec 3< $1 4> $2
			;;
		*)
			echo "Usage: mycp [source[dest]]"
			return 1
			;;
	esac

# Call cat with input from FD(3) and output going to FD(4)
cat <&3 >&4

# Close FD's FD(3) and FD(4)
exec 3<&- 4<&-
}
